# Whist Backend

[![Lint](https://github.com/Danie-1/whist_backend/actions/workflows/lint.yml/badge.svg)](https://github.com/Danie-1/whist_backend/actions/workflows/lint.yml)
[![Tests](https://github.com/Danie-1/whist_backend/actions/workflows/tests.yml/badge.svg)](https://github.com/Danie-1/whist_backend/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/whist-backend/badge/?version=latest)](https://whist-backend.readthedocs.io/en/latest/?badge=latest)
[![PyPI Version](https://img.shields.io/pypi/v/whist_backend.svg)](https://pypi.python.org/pypi/whist_backend)

To install, run
```
pip install whist-backend
```

# Examples

See the `examples` folder of this repository for example usage, or view the
[Example page in the documentation](https://whist-backend.readthedocs.io/en/latest/example.html).
